@@ -1,13 +1,13 @@
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-[assembly: AssemblyVersion("0.7.1")]
+[assembly: AssemblyVersion("0.7.3")]
 [assembly: AssemblyTitle("themonospot-base")]
 [assembly: AssemblyDescription("Parser/editor and content descriptor for .avi and .mkv file types")]
 [assembly: AssemblyConfiguration("")]
-[assembly: AssemblyCompany("hmandevteam")]
+[assembly: AssemblyCompany("Armando Basile")]
 [assembly: AssemblyProduct("themonospot-base")]
-[assembly: AssemblyCopyright("GPL")]
+[assembly: AssemblyCopyright("Armando Basile")]
 [assembly: AssemblyTrademark("None")]
 [assembly: AssemblyDelaySign(false)]
 [assembly: AssemblyKeyFile("")]
